# app_config Changelog

## 2.0.4  / 2026-01-04
 
  - Python 3.14 configparser removed _prefix; changed to use
    sys_comment_prefixes in the sys section of config module

## 2.0.3  / 2025-08-28
 
  - addition of gitlab ci/cd

## 2.0.2  / 2025-08-28
 
  - Documentation updates

## 2.0.1  / 2025-06-18
 
  - Documentation updates

## 2.0.0  / 2025-06-16

- Rename config-tpg to app-config
- Update doc 

This package was originally releases in Dec of 2024 as config-tpg.  It
has been renamed to app-config.  Because pypi keeps the history and the 
original unused app-config package was version 1.0.1, the 2.0.0 provides
a clean break.

## 0.1.5  / 2025-03-24

- final version of config-tpg

## 0.0.1  / 2025-01-07

- initial load to production pypi

## 0.0.1  / 2024-12-10

- initial load to test pypi

## 0.0.0  / 2023-07-16

- developed code in application

